Module: Users
- Included in:
- Volabit::API
- Defined in:
- lib/volabit/api/users.rb
Overview
API endpoints for user account management.
Instance Method Summary collapse
-
#create_user(acceptance:, email:, pass: '') ⇒ Object
(also: #new_user)
Request the creation of a new user with the given params.
-
#me ⇒ Object
(also: #user_data)
Gets the information details of the app user.
Instance Method Details
#create_user(acceptance:, email:, pass: '') ⇒ Object Also known as: new_user
Note:
This action requires partner privileges.
Request the creation of a new user with the given params.
6 7 8 9 10 11 12 13 |
# File 'lib/volabit/api/users.rb', line 6 def create_user(acceptance:, email:, pass: '') resource :post, 'api/v1/users', accepts_terms_of_service: acceptance, user: { email: email, password: pass } end |
#me ⇒ Object Also known as: user_data
Gets the information details of the app user.
18 19 20 |
# File 'lib/volabit/api/users.rb', line 18 def me resource :get, 'api/v1/users/me' end |